@@ -222,6 +222,14 @@ def get_parser(only=None, printer=None):
         nargs='+',
         help=prt.text('parser_user_fixed_parameters'))
 
+    parser.add_argument(
+        '--release-parameters',
+        '-r',
+        dest='user_released_parameters',
+        default=[],
+        nargs='+',
+        help=prt.text('parser_user_released_parameters'))
+
     parser.add_argument(
         '--iterations',
         '-i',
@@ -505,8 +513,8 @@ def get_parser(only=None, printer=None):
         '--extra-outputs',
         '-x',
         dest='extra_outputs',
-        default=[],
-        nargs='+',
+        default=None,
+        nargs='*',
         help=prt.text('parser_extra_outputs'))
 
     parser.add_argument(
@@ -629,6 +637,24 @@ def main():
     args.method = 'nester' if args.method.lower() in [
         'nest', 'nested', 'nested_sampler', 'nester'] else 'ensembler'
 
+    if is_master():
+        if args.method == 'nester':
+            unused_args = [
+                [args.burn, '-b'],
+                [args.post_burn, '-p'],
+                [args.frack_step, '-f'],
+                [args.num_temps, '-T'],
+                [args.run_until_uncorrelated, '-U'],
+                [args.draw_above_likelihood, '-d'],
+                [args.gibbs, '-g'],
+                [args.save_full_chain, '-c'],
+                [args.maximum_memory, '-M']
+            ]
+            for ua in unused_args:
+                if ua[0] is not None:
+                    prt.message('argument_not_used',
+                                reps=[ua[1], '-D nester'], warning=True)
+
     if args.method == 'nester':
         if args.run_until_converged and args.iterations >= 0:
             raise ValueError(prt.text('R_i_mutually_exclusive'))
@@ -760,23 +786,6 @@ def main():
 
         upload_token_path = os.path.join(dir_path, 'cache', 'dropbox.token')
 
-        if args.method == 'nester':
-            unused_args = [
-                [args.burn, '-b'],
-                [args.post_burn, '-p'],
-                [args.frack_step, '-f'],
-                [args.num_temps, '-T'],
-                [args.run_until_uncorrelated, '-U'],
-                [args.draw_above_likelihood, '-d'],
-                [args.gibbs, '-g'],
-                [args.save_full_chain, '-c'],
-                [args.maximum_memory, '-M']
-            ]
-            for ua in unused_args:
-                if ua[0] is not None:
-                    prt.message('argument_not_used',
-                                reps=[ua[1], '-D nester'], warning=True)
-
         # Perform a few checks on upload before running (to keep size
         # manageable)
         if args.upload and not args.test and args.smooth_times > 100:
